@@ -5,8 +5,9 @@
 from __future__ import print_function
 from collections import namedtuple
 import inspect
+import sys
 
-__version__ = '0.0.3'
+__version__ = '0.0.5'
 
 # Holds information about where the debug print came from.
 LineInfo = namedtuple('LineInfo', ['filename', 'name', 'lineno'])
@@ -63,14 +64,26 @@ def printdebug(*args, **kwargs):
     print(debugstr, **kwargs)
 
 
-def printobject(obj, indent=0):
+def printobject(obj, file=None, indent=0):
     """ Print a verbose representation of an object.
         The format depends on what kind of object it is.
         Tuples, Lists, and Dicts are recursively formatted according to the
         other rules below.
         Strings will be printed as is.
         Any other type will be printed using str() (Actually '{}'.format(obj))
+        Arguments:
+            obj    : Object to print.
+            file     : Open file object, defaults to sys.stdout.
+            indent : Internal use. Can be used to set initial indention though.
+                     Must be an integer. Default: 0
     """
+    if file is None:
+        file = sys.stdout
+
+    if not hasattr(file, 'write'):
+        errfmt = 'file must have a "write" method. Got: {} ({!r})'
+        raise TypeError(errfmt.format(type(file), file))
+
     if isinstance(obj, dict):
         try:
             objkeys = sorted(obj.keys())
@@ -80,13 +93,13 @@ def printobject(obj, indent=0):
 
         for k in objkeys:
             v = obj[k]
-            print('{}{}:'.format(' ' * indent, k))
+            print('{}{}:'.format(' ' * indent, k), file=file)
             if isinstance(v, dict):
-                printobject(v, indent=indent + 4)
+                printobject(v, file=file, indent=indent + 4)
             elif isinstance(v, (list, tuple)):
-                printobject(v, indent=indent + 4)
+                printobject(v, file=file, indent=indent + 4)
             else:
-                print('{}{}'.format(' ' * (indent + 4), v))
+                print('{}{}'.format(' ' * (indent + 4), v), file=file)
     elif isinstance(obj, (list, tuple)):
         try:
             objitems = sorted(obj)
@@ -96,8 +109,8 @@ def printobject(obj, indent=0):
 
         for itm in objitems:
             if isinstance(itm, (list, tuple)):
-                printobject(itm, indent=indent + 4)
+                printobject(itm, file=file, indent=indent + 4)
             else:
-                print('{}{}'.format(' ' * indent, itm))
+                print('{}{}'.format(' ' * indent, itm), file=file)
     else:
-        print('{}{}'.format(' ' * indent, obj))
+        print('{}{}'.format(' ' * indent, obj), file=file)
